Rev 5359: Rename IniBaseConfig.from_bytes to from_string. in file:///home/vila/src/bzr/bugs/525571-lock-bazaar-conf-files/

Vincent Ladeuil v.ladeuil+lp at free.fr
Sat Aug 28 17:56:36 BST 2010


At file:///home/vila/src/bzr/bugs/525571-lock-bazaar-conf-files/

------------------------------------------------------------
revno: 5359
revision-id: v.ladeuil+lp at free.fr-20100828165636-8e2wziacdpog1adg
parent: v.ladeuil+lp at free.fr-20100824080512-o579ni033c75lkue
committer: Vincent Ladeuil <v.ladeuil+lp at free.fr>
branch nick: simplify-test-config-building
timestamp: Sat 2010-08-28 18:56:36 +0200
message:
  Rename IniBaseConfig.from_bytes to from_string.
-------------- next part --------------
=== modified file 'NEWS'
--- a/NEWS	2010-08-24 08:05:12 +0000
+++ b/NEWS	2010-08-28 16:56:36 +0000
@@ -133,8 +133,8 @@
 API Changes
 ***********
 
-* Configuration files should now use the ``from_bytes`` constructor the
-  rather than the ``file`` parameter of the ``_get_parser`` method. The
+* ``IniBaseConfig`` objects should now use the ``from_string`` constructor
+  the rather than the ``file`` parameter of the ``_get_parser`` method. The
   later has been deprecated. (Vincent Ladeuil)
 
 * InventoryEntry instances now raise AttributeError if you try to assign
@@ -149,10 +149,6 @@
 * InventoryEntry objects no longer have ``_put_in_tar`` or
   ``_put_on_disk`` methods.  (Andrew Bennetts)
 
-* The ``configIniBaseConfig`` constructor now accepts a ``_content``
-  private parameter for tests that want to provide a config file content.
-  (Vincent Ladeuil)
-
 * The ``get_filename`` parameter in the ``config.IniBaseConfig``
   constructor has been deprecated, use the ``file_name`` parameter instead.
   (Vincent Ladeuil)

=== modified file 'bzrlib/config.py'
--- a/bzrlib/plugins/launchpad/test_account.py	2010-08-24 08:05:12 +0000
+++ b/bzrlib/plugins/launchpad/test_account.py	2010-08-28 16:56:36 +0000
@@ -26,7 +26,7 @@
 class LaunchpadAccountTests(TestCaseInTempDir):
 
     def setup_config(self, text):
-        my_config = config.GlobalConfig.from_bytes(text)
+        my_config = config.GlobalConfig.from_string(text)
         return my_config
 
     def test_get_lp_login_unconfigured(self):

=== modified file 'bzrlib/tests/test_commands.py'
--- a/bzrlib/tests/test_commands.py	2010-08-24 08:05:12 +0000
+++ b/bzrlib/tests/test_commands.py	2010-08-28 16:56:36 +0000
@@ -95,7 +95,7 @@
 class TestGetAlias(tests.TestCase):
 
     def _get_config(self, config_text):
-        my_config = config.GlobalConfig.from_bytes(config_text)
+        my_config = config.GlobalConfig.from_string(config_text)
         return my_config
 
     def test_simple(self):

=== modified file 'bzrlib/tests/test_config.py'
--- a/bzrlib/tests/test_config.py	2010-08-24 08:05:12 +0000
+++ b/bzrlib/tests/test_config.py	2010-08-28 16:56:36 +0000
@@ -367,7 +367,7 @@
 class TestIniConfig(tests.TestCaseInTempDir):
 
     def make_config_parser(self, s):
-        conf = config.IniBasedConfig.from_bytes(s)
+        conf = config.IniBasedConfig.from_string(s)
         return conf, conf._get_parser()
 
 
@@ -377,11 +377,11 @@
         my_config = config.IniBasedConfig()
 
     def test_from_fp(self):
-        my_config = config.IniBasedConfig.from_bytes(sample_config_text)
+        my_config = config.IniBasedConfig.from_string(sample_config_text)
         self.assertIsInstance(my_config._get_parser(), configobj.ConfigObj)
 
     def test_cached(self):
-        my_config = config.IniBasedConfig.from_bytes(sample_config_text)
+        my_config = config.IniBasedConfig.from_string(sample_config_text)
         parser = my_config._get_parser()
         self.failUnless(my_config._get_parser() is parser)
 
@@ -409,7 +409,7 @@
 
     def test_get_parser_file_parameter_is_deprecated_(self):
         config_file = StringIO(sample_config_text.encode('utf-8'))
-        conf = config.IniBasedConfig.from_bytes(sample_config_text)
+        conf = config.IniBasedConfig.from_string(sample_config_text)
         conf = self.callDeprecated([
             'IniBasedConfig._get_parser(file=xxx) was deprecated in 2.3.'
             ' Use IniBasedConfig(_content=xxx) instead.'],
@@ -607,7 +607,7 @@
 class TestGlobalConfigItems(tests.TestCase):
 
     def test_user_id(self):
-        my_config = config.GlobalConfig.from_bytes(sample_config_text)
+        my_config = config.GlobalConfig.from_string(sample_config_text)
         self.assertEqual(u"Erik B\u00e5gfors <erik at bagfors.nu>",
                          my_config._get_user_id())
 
@@ -616,11 +616,11 @@
         self.assertEqual(None, my_config._get_user_id())
 
     def test_configured_editor(self):
-        my_config = config.GlobalConfig.from_bytes(sample_config_text)
+        my_config = config.GlobalConfig.from_string(sample_config_text)
         self.assertEqual("vim", my_config.get_editor())
 
     def test_signatures_always(self):
-        my_config = config.GlobalConfig.from_bytes(sample_always_signatures)
+        my_config = config.GlobalConfig.from_string(sample_always_signatures)
         self.assertEqual(config.CHECK_NEVER,
                          my_config.signature_checking())
         self.assertEqual(config.SIGN_ALWAYS,
@@ -628,7 +628,7 @@
         self.assertEqual(True, my_config.signature_needed())
 
     def test_signatures_if_possible(self):
-        my_config = config.GlobalConfig.from_bytes(sample_maybe_signatures)
+        my_config = config.GlobalConfig.from_string(sample_maybe_signatures)
         self.assertEqual(config.CHECK_NEVER,
                          my_config.signature_checking())
         self.assertEqual(config.SIGN_WHEN_REQUIRED,
@@ -636,7 +636,7 @@
         self.assertEqual(False, my_config.signature_needed())
 
     def test_signatures_ignore(self):
-        my_config = config.GlobalConfig.from_bytes(sample_ignore_signatures)
+        my_config = config.GlobalConfig.from_string(sample_ignore_signatures)
         self.assertEqual(config.CHECK_ALWAYS,
                          my_config.signature_checking())
         self.assertEqual(config.SIGN_NEVER,
@@ -644,7 +644,7 @@
         self.assertEqual(False, my_config.signature_needed())
 
     def _get_sample_config(self):
-        my_config = config.GlobalConfig.from_bytes(sample_config_text)
+        my_config = config.GlobalConfig.from_string(sample_config_text)
         return my_config
 
     def test_gpg_signing_command(self):
@@ -993,9 +993,9 @@
             global_config = sample_config_text
 
         config.ensure_config_dir_exists()
-        my_global_config = config.GlobalConfig.from_bytes(global_config)
+        my_global_config = config.GlobalConfig.from_string(global_config)
         my_global_config._write_config_file()
-        my_location_config = config.LocationConfig.from_bytes(
+        my_location_config = config.LocationConfig.from_string(
             sample_branches_text, my_branch.base)
         my_location_config._write_config_file()
 
@@ -1068,11 +1068,11 @@
                           location_config=None, branch_data_config=None):
         my_branch = FakeBranch(location)
         if global_config is not None:
-            my_global_config = config.GlobalConfig.from_bytes(global_config)
+            my_global_config = config.GlobalConfig.from_string(global_config)
             config.ensure_config_dir_exists()
             my_global_config._write_config_file()
         if location_config is not None:
-            my_location_config = config.LocationConfig.from_bytes(
+            my_location_config = config.LocationConfig.from_string(
                 location_config, my_branch.base)
             config.ensure_config_dir_exists()
             my_location_config._write_config_file()

=== modified file 'bzrlib/tests/test_smtp_connection.py'
--- a/bzrlib/tests/test_smtp_connection.py	2010-08-24 08:05:12 +0000
+++ b/bzrlib/tests/test_smtp_connection.py	2010-08-28 16:56:36 +0000
@@ -91,7 +91,7 @@
 class TestSMTPConnection(tests.TestCaseInTempDir):
 
     def get_connection(self, text, smtp_factory=None):
-        my_config = config.GlobalConfig.from_bytes(text)
+        my_config = config.GlobalConfig.from_string(text)
         return smtp_connection.SMTPConnection(my_config,
                                               _smtp_factory=smtp_factory)
 



More information about the bazaar-commits mailing list
--- a/bzrlib/config.py	2010-08-24 08:05:12 +0000
+++ b/bzrlib/config.py	2010-08-28 16:56:36 +0000
@@ -377,14 +377,14 @@
         self._parser = None
 
     @classmethod
-    def from_bytes(cls, unicode_bytes):
+    def from_string(cls, str_or_unicode):
         """Create a config object from bytes.
 
         :param unicode_bytes: A string representing the file content. This will
             be utf-8 encoded.
         """
         conf = cls()
-        conf._content = StringIO(unicode_bytes.encode('utf-8'))
+        conf._content = StringIO(str_or_unicode.encode('utf-8'))
         return conf
 
     def _get_parser(self, file=symbol_versioning.DEPRECATED_PARAMETER):
@@ -581,16 +581,16 @@
         self.location = location
 
     @classmethod
-    def from_bytes(cls, unicode_bytes, location):
+    def from_string(cls, str_or_unicode, location):
         """Create a config object from bytes.
 
         :param unicode_bytes: A string representing the file content. This will
             be utf-8 encoded.
 
         :param location: The location url to filter the configuration.
         """
         conf = cls(location)
-        conf._content = StringIO(unicode_bytes.encode('utf-8'))
+        conf._content = StringIO(str_or_unicode.encode('utf-8'))
         return conf
 
     def _get_matching_sections(self):
@@ -377,14 +377,14 @@
         """Create a config object from bytes.
 
-        :param unicode_bytes: A string representing the file content. This will
+        :param str_or_unicode: A string representing the file content. This will
             be utf-8 encoded.
         """
@@ -581,16 +581,16 @@
         """Create a config object from bytes.
 
-        :param unicode_bytes: A string representing the file content. This will
+        :param str_or_unicode: A string representing the file content. This will
             be utf-8 encoded.
 

=== modified file 'bzrlib/plugins/launchpad/test_account.py'